@@ -60,7 +60,7 @@ impl<'a> Paf<'a> {
         for (index, line) in io::BufReader::new(paf_file).lines().enumerate() {
             match PafRecord::new(&line.unwrap()) {
                 Ok(rec) => {
-                    eprint!("\rReading PAF entry # {}", index);
+                    //eprint!("\rReading PAF entry # {}", index);
                     records.push(rec)
                 }
                 Err(_) => eprintln!("\nUnable to parse PAF record. Skipping line {}", index + 1),
